// BWCurveWindowController.m -- mediate between the window controls
//				and the BWCurveCanvas that shows the
//				interesting stuff

// Copyright (C) 2002 Borkware
// We use the BSD License.  Check out http://borkware.com/license

#import "BWCurveWindowController.h"
#import "BWCurveCanvas.h"


// Different fill values we can apply to the curve.
// The values match the tags on the items in a popup menu
enum {
    kNoFill = 0,
    kNonZeroFill,
    kEvenOddFill
};


@implementation BWCurveWindowController

- (void) awakeFromNib
{
    // set some defaults
    [pinPointsButton setEnabled: NO];
    [curveCanvas setFlatness: 1.0];
    [flatnessSlider setFloatValue: 1.0];

} // awakeFromNib



// move all the control points into the visible region

- (IBAction) pinPoints: (id) sender
{
    [curveCanvas pinPoints];
} // pinPoints



//  track the flatness slider.  The flatness is how chunky curves get

- (IBAction) setFlatness: (id) sender
{
    [curveCanvas setFlatness: [flatnessSlider floatValue]];
} // setFlatness



// turn on/off the fill for the curve, and also choose the fill style

- (IBAction) setFill: (id) sender
{
    int windingRule = -1;
    NSMenuItem *item;

    item = [sender selectedItem];

    switch ([item tag]) {

        case kNoFill:
	    windingRule = -1;
	    break;

        case kNonZeroFill:
	    windingRule = NSNonZeroWindingRule;
	    break;

        case kEvenOddFill:
	    windingRule = NSEvenOddWindingRule;
	    break;
    }

    [curveCanvas setFill: windingRule];
    [curveCanvas setNeedsDisplay: YES];

} // setFill



// return the points to the initial value 

- (IBAction) resetPoints: (id) sender
{
    [curveCanvas resetPoints];
    [curveCanvas setNeedsDisplay: YES];

} // resetPoints



// delegate methods from the curve canvas

// a control point has moved out of frame.  Enable the button
// so the user can move it into rame

- (void) pointOutOfFrame
{
    [pinPointsButton setEnabled: YES];
} // pointOutOfFrame


// all control points are visible.  no need to leave enabled the
// 'pin points' button

- (void) allPointsInFrame
{
    [pinPointsButton setEnabled: NO];
} // allPointsInFrame


@end // BWCurveWindowController
