// BWImageWindowControlle.mr -- mediate between the window gadgets and the
//			        image canvas that applies transforms to an
//	  		        image

// Copyright (C) 2002 Borkware
// We use the BSD License.  Check out http://borkware.com/license

#import "BWImageWindowController.h"
#import "BWImageCanvas.h"

@implementation BWImageWindowController

// the window has an NSMatrix of text fields that gets set with
// values from the transformation matrix.

- (void) updateMatrix
{
    NSAffineTransform *transform = [imageCanvas currentTransform];
    NSAffineTransformStruct tstruct = [transform transformStruct];
    NSCell *cell;

    cell = [matrixMatrix cellAtRow: 0 column: 0];
    [cell setFloatValue: tstruct.m11];
    cell = [matrixMatrix cellAtRow: 0 column: 1];
    [cell setFloatValue: tstruct.m12];
    cell = [matrixMatrix cellAtRow: 0 column: 2];
    [cell setFloatValue: 0.0];
    
    cell = [matrixMatrix cellAtRow: 1 column: 0];
    [cell setFloatValue: tstruct.m21];
    cell = [matrixMatrix cellAtRow: 1 column: 1];
    [cell setFloatValue: tstruct.m22];
    cell = [matrixMatrix cellAtRow: 1 column: 2];
    [cell setFloatValue: 0.0];
    
    cell = [matrixMatrix cellAtRow: 2 column: 0];
    [cell setFloatValue: tstruct.tX];
    cell = [matrixMatrix cellAtRow: 2 column: 1];
    [cell setFloatValue: tstruct.tY];
    cell = [matrixMatrix cellAtRow: 2 column: 2];
    [cell setFloatValue: 1.0];
    
} // updateMatrix



// restore the UI to default values

- (void) resetUI
{
    [scaleXSlider setFloatValue: defaultScaleX];
    [scaleYSlider setFloatValue: defaultScaleY];
    [translateXSlider setFloatValue: defaultTranslateX];
    [translateYSlider setFloatValue: defaultTranslateY];
    [rotateSlider setFloatValue: defaultRotation];

    [self updateMatrix];

} // resetUI



- (void) awakeFromNib
{
    defaultScaleX = [imageCanvas scaleX];
    defaultScaleY = [imageCanvas scaleY];
    defaultTranslateX = [imageCanvas translateX];
    defaultTranslateY = [imageCanvas translateY];
    defaultRotation = [imageCanvas rotation];

    [self resetUI];

} // awakeFromNib



- (IBAction) setScaleX: (id) sender
{
    [imageCanvas setScaleX: [sender floatValue]];
    [self updateMatrix];
} // setScaleX



- (IBAction) setScaleY: (id) sender
{
    [imageCanvas setScaleY: [sender floatValue]];
    [self updateMatrix];
} // setScaleY



- (IBAction) setTranslateX: (id) sender
{
    [imageCanvas setTranslateX: [sender floatValue]];
    [self updateMatrix];
} // setTranslateX



- (IBAction) setTranslateY: (id) sender
{
    [imageCanvas setTranslateY: [sender floatValue]];
    [self updateMatrix];
} // setTranslateY



- (IBAction) setRotate: (id) sender
{
    [imageCanvas setRotation: [sender floatValue]];
    [self updateMatrix];
} // setRotate


// handle the reset button to restore the defaults

- (IBAction) reset: (id) sender
{
    [imageCanvas setScaleX: defaultScaleX];
    [imageCanvas setScaleY: defaultScaleY];
    [imageCanvas setTranslateX: defaultTranslateX];
    [imageCanvas setTranslateY: defaultTranslateY];
    [imageCanvas setRotation: defaultRotation];

    [self resetUI];

} // reset


@end // BWImageWindowController

