// BWLineDash(View).m -- show the effects of line dash parameters

// Copyright (C) 2002 Borkware
// We use the BSD License.  Check out http://borkware.com/license

#import "BWLineDash.h"

#define DEFAULT_LINE_WIDTH 	5

static float g_pattern[] = { 5, 1, 4, 1, 3, 1, 2, 1, 1, 1, 1, 2, 1, 3, 1, 4, 1, 5 };


@implementation BWLineDash

// create a straight path.  there's actually two lines.  One horizontal,
// one at an angle

- (NSBezierPath *) makeStraightPath: (NSRect) frame
{
    NSBezierPath *newPath;
    float y;

    newPath = [NSBezierPath bezierPath];
    [newPath setLineWidth: DEFAULT_LINE_WIDTH];
    
    y = frame.size.height * 0.2;
    [newPath moveToPoint: NSMakePoint (0, y)];
    [newPath lineToPoint: NSMakePoint (frame.size.width, y)];
    
    y = frame.size.height * 0.5;
    [newPath moveToPoint: NSMakePoint (0, y)];
    y = frame.size.height * 0.9;
    [newPath lineToPoint: NSMakePoint (frame.size.width, y)];
    
    pattern = malloc (sizeof(g_pattern));
    memcpy (pattern, g_pattern, sizeof(g_pattern));
    count = sizeof (g_pattern) / sizeof (float);
    phase = 0.0;
    
    [newPath setLineDash: pattern count: count phase: phase];
    
    return (newPath);

} // makeStraightPath



// make a sine-wave kind of path

- (NSBezierPath *) makeCurvedPath: (NSRect) frame
{
    NSBezierPath *newPath;
    NSPoint start, end;
    NSPoint control1, control2;
    float midX, midY;

    midX = frame.size.width / 2;
    midY = frame.size.height / 2;

    newPath = [NSBezierPath bezierPath];
    [newPath setLineWidth: DEFAULT_LINE_WIDTH];

    // make the first hump
    start = NSMakePoint (0, midY);
    [newPath moveToPoint: start];

    end = NSMakePoint (midX, midY);
    control1 = NSMakePoint (midX * 0.33, frame.size.height);
    control2 = NSMakePoint (midX * 0.66, frame.size.height);
    [newPath curveToPoint: end  
	     controlPoint1: control1  
	     controlPoint2: control2];

    end = NSMakePoint (frame.size.width, midY);
    control1 = NSMakePoint (midX + (midX * 0.33), 0);
    control2 = NSMakePoint (midX + (midX * 0.66), 0);
    [newPath curveToPoint: end  
	     controlPoint1: control1  
	     controlPoint2: control2];

    pattern = malloc (sizeof(g_pattern));
    memcpy (pattern, g_pattern, sizeof(g_pattern));
    count = sizeof (g_pattern) / sizeof (float);
    phase = 0.0;
    
    [newPath setLineDash: pattern count: count phase: phase];
    
    return (newPath);

} // makeCurvedPath



- (id) initWithFrame: (NSRect) frame 
{
    if (self = [super initWithFrame: frame]) {
	curved = NO;
	path = [self makeStraightPath: frame];
	[path retain];
    }

    return (self);

} // initWithFrame



- (void) drawRect: (NSRect) rect 
{
    rect = [self bounds];
    
    [[NSColor whiteColor] set];
    [NSBezierPath fillRect: rect];
    [[NSColor blackColor] set];
    [NSBezierPath strokeRect: rect];

    [path stroke];

} // drawRect


// change to/from a curved path

- (void) setCurved: (BOOL) c
{
    [path release];

    curved = c;

    if (curved) {
	path = [self makeCurvedPath: [self bounds]];
    } else {
	path = [self makeStraightPath: [self bounds]];
    }

    [path retain];

} // setCurved



- (void) setLineWidth: (float) lineWidth
{
    [path setLineWidth: lineWidth];
} // setLineWidth



- (void) setLinePhase: (float) p
{
    phase = p;

    [path setLineDash: pattern  count: count  phase: phase];
    
} // setLineWidth



- (void) setLineDash: (const float *) pt  count: (int) c
{
    float *newPattern;

    count = c;

    newPattern = malloc (sizeof(float) * count);

    memcpy (newPattern, pt, sizeof(float) * count);
    free (pattern);
    pattern = newPattern;

    [path setLineDash: pattern  count: count  phase: phase];

} // setLineDash



- (void) dealloc
{
    [path release];
	[super dealloc];
} // dealloc


@end // BWLineDash


