// BWQuartzViewDemo.h -- play with Quartz (Core Graphics) directly.  these
//		         some sample bits of code lifted from the Apple
//		         intro to quartz documentation

// Copyright (C) 2002 Borkware
// We use the BSD License.  Check out http://borkware.com/license

#import "BWQuartzViewDemo.h"


// draw a bunch of lines radiating from a central point

static void DrawStarburst (CGContextRef context, float size, int rayCount,
			   int x, int y)
{
    const float kFullCircleInRadians = 3.14159265358979323846 * 2.0;
    float rotation;
    
    CGContextSaveGState (context); {

	for (rotation = 0.0;
	     rotation < kFullCircleInRadians;
	     rotation += (kFullCircleInRadians / rayCount)) {
	    
	    CGContextMoveToPoint (context, x, y);
	    CGContextAddLineToPoint (context, sin(rotation) * size + x,
				     cos(rotation) * size + y);
	}
	
	CGContextStrokePath (context);
	CGContextRestoreGState (context);
    }
    
} // DrawStarburst



@implementation BWQuartzViewDemo

// draw stuff.  And/or a starburst, or "Borkware" as a clip mask.
// the superclass will save the graphics state

- (void) drawRect: (NSRect) rect  withContext: (CGContextRef) context
{
    const char *text = "Borkware";

    // fill in the area with a nice orane color
    CGRect crect = BWConvertToCGRect(rect);
    CGContextSetRGBFillColor (context, 1.0, 0.5, 0.25, 1.0);

    CGContextFillRect (context, crect);

    // and give it a flat black frame
    [[NSColor blackColor] set];
    CGContextStrokeRect (context, crect);
    
    if (clipToText) {
	
	CGContextSelectFont (context, "Helvetica-Bold", 
			     80.0, kCGEncodingMacRoman);
	CGContextSetTextDrawingMode (context, kCGTextStrokeClip);
	CGContextShowTextAtPoint (context, 0.0, 
				  crect.size.height * 0.25,
				  text, strlen(text));
	
	// fill it in with a nice blue color
	CGContextSetRGBFillColor (context, 0.4, 0.7, 0.9, 1.0);
	CGRect bigRect = CGRectMake (-2000.0, -2000.0, 4000.0, 4000.0);
	CGContextFillRect (context, bigRect);
    }
    
    if (fannedLines) {
	// apply the translation and rotation to the starburst
	
	CGContextTranslateCTM (context, translationX, translationY);
	CGContextRotateCTM (context, rotation);
	
	// and draw it in black
	CGContextSetRGBStrokeColor (context, 0.0, 0.0, 0.0, 1.0);
	DrawStarburst (context, 5000, 80, 0, 0);
    }

} // drawRect withContext



- (void) setFannedLines: (BOOL) onOff
{
    fannedLines = onOff;
} // setFannedLines



- (void) setClipToText: (BOOL) onOff
{
    clipToText = onOff;
} // setClipToText



- (void) setRotation: (float) angle
{
    rotation = angle;
} // setRotation



- (void) setTranslationX: (float) x
{
    translationX = x;
} // setTranslationX



- (void) setTranslationY: (float) y
{
    translationY = y;
} // setTranslationY

@end // BWQuartzViewDemo

