// LineWindowController.m -- Drive the Line window.  This is an ancient
//			     file, hence the lack of a 'BW' prefix.

// Copyright (C) 2002 Borkware
// We use the BSD License.  Check out http://borkware.com/license


#import "LineWindowController.h"

#import "BWLineCap.h"
#import "BWLineJoin.h"
#import "BWLineDash.h"
#import "BWDashController.h"

// these both match the tags on the items in a popup menu
enum {
    kButtCap = 0,
    kRoundCap,
    kSquareCap
};

enum {
    kMiterJoin = 0,
    kRoundJoin,
    kBevelJoin
};


@implementation LineWindowController


- (void) awakeFromNib
{
    [curveDash setCurved: YES];
} // awakeFromNib


// UI item actions

- (IBAction) setCapLineWidth: (id) sender
{
    [lineCap setLineWidth: [sender floatValue]];
    [lineCap setNeedsDisplay: YES];
} // setCapLineWidth



- (IBAction) setCapStyle: (id) sender
{
    NSLineCapStyle cap;
    NSMenuItem *item;

    item = [sender selectedItem];

    switch ([item tag]) {

        case kButtCap:
    	    cap = NSButtLineCapStyle;
    	    break;

        case kRoundCap:
	    cap = NSRoundLineCapStyle;
	    break;

        case kSquareCap:
	    cap = NSSquareLineCapStyle;
	    break;

        default:
	    NSLog (@"setCapStyle: bad value: %d", [item tag]);
    	    cap = NSButtLineCapStyle;
  	    break;
    }

    [lineCap setLineCapStyle: cap];
    [lineCap setNeedsDisplay: YES];

} // setCapStyle



- (IBAction) setJoinLineWidth: (id) sender
{
    [lineJoin setLineWidth: [sender floatValue]];
    [lineJoin setNeedsDisplay: YES];
} // setJoinLineWidth



- (IBAction) setJoinMiterLimit: (id) sender
{
    [lineJoin setMiterLimit: [sender floatValue]];
    [lineJoin setNeedsDisplay: YES];
} // setJoinMiterLimit



- (IBAction) setJoinStyle: (id) sender
{
    NSLineJoinStyle join;
    NSMenuItem *item;

    item = [sender selectedItem];

    switch ([item tag]) {

        case kMiterJoin:
    	    join = NSMiterLineJoinStyle;
    	    break;

        case kRoundJoin:
	    join = NSRoundLineJoinStyle;
	    break;

        case kBevelJoin:
	    join = NSBevelLineJoinStyle;
	    break;

        default:
	    NSLog (@"setJoinStyle: bad value: %d", [item tag]);
    	    join = NSMiterLineJoinStyle;
  	    break;
    }

    [lineJoin setLineJoinStyle: join];
    [lineJoin setNeedsDisplay: YES];

} // setJoinStyle



- (IBAction) setDashLineWidth: (id) sender
{
    [lineDash setLineWidth: [sender floatValue]];
    [lineDash setNeedsDisplay: YES];

    [curveDash setLineWidth: [sender floatValue]];
    [curveDash setNeedsDisplay: YES];

} // setDashLineWidth



- (IBAction) setDashLinePhase: (id) sender
{
    [lineDash setLinePhase: [sender floatValue]];
    [lineDash setNeedsDisplay: YES];

    [curveDash setLinePhase: [sender floatValue]];
    [curveDash setNeedsDisplay: YES];

} // setDashLineWidth



- (IBAction) updateDashPattern: (id) sender
{
    // assume the sender is a BWDashController
    BWDashController *dashes = (BWDashController *)sender;
    int count;
    const float *pattern;

    count = [dashes count];
    pattern = [dashes pattern];

    [lineDash setLineDash: pattern  count: count];
    [lineDash setNeedsDisplay: YES];

    [curveDash setLineDash: pattern  count: count];
    [curveDash setNeedsDisplay: YES];

} // updateDashPattern


@end // LineWindowController

